@@ -2,10 +2,11 @@
 
 from ppp_libmodule import HttpRequestHandler
 from .preprocessingMerge import mergeNamedEntityTagChildParent, mergeNamedEntityTagSisterBrother, mergeNamedEntityTag
-from .preprocessing import Word, DependenciesTree, computeTree
+from .preprocessing import Word, DependenciesTree, computeTree, QuotationHandler
 from .questionWordProcessing import identifyQuestionWord
 from .dependencyAnalysis import simplify
 from .normalization import normalize
+from .data.exceptions import QuotationError
 
 from .requesthandler import RequestHandler
 
@@ -14,4 +15,4 @@ def app(environ, start_response):
     return HttpRequestHandler(environ, start_response, RequestHandler) \
             .dispatch()
 
-__all__ = ['DependenciesTree','computeTree','mergeNamedEntityTagChildParent','mergeNamedEntityTagSisterBrother','mergeNamedEntityTag','simplify', 'identifyQuestionWord','normalize']
+__all__ = ['DependenciesTree','computeTree','QuotationHandler','mergeNamedEntityTagChildParent','mergeNamedEntityTagSisterBrother','mergeNamedEntityTag','simplify', 'identifyQuestionWord','normalize','QuotationError']
